/*
 * Copyright 2012-2015 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.setup.command.internal;

import com.redhat.thermostat.setup.command.locale.LocaleResources;
import com.redhat.thermostat.shared.locale.Translate;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.LayoutManager;
import java.net.URL;

public class UserPropertiesView extends JPanel implements SetupView {

    private JButton finishBtn;
    private JButton backBtn;
    private JButton cancelBtn;

    private JPanel toolbar;
    private JPanel midPanel;
    private JPanel detailsPanel;
    private JCheckBox makeAgentUserBtn;
    private JCheckBox makeClientAdminBtn;

    private static final String THERMOSTAT_LOGO = "thermostat.png";
    private static final String PROGRESS = "Step 3 of 3";
    private static final Translate<LocaleResources> translator = LocaleResources.createLocalizer();

    public UserPropertiesView(LayoutManager layout) {
        super(layout);

        createMidPanel();
        createToolbarPanel();

        this.add(midPanel, BorderLayout.CENTER);
        this.add(toolbar, BorderLayout.SOUTH);
    }

    @Override
    public void setTitleAndProgress(JLabel title, JLabel progress) {
        title.setText(translator.localize(LocaleResources.USERS_SETUP_TITLE).getContents());
        progress.setText(PROGRESS);
    }

    public void createMidPanel() {
        JLabel agentInfo = new JLabel(translator.localize(LocaleResources.AGENT_INFO).getContents());
        JLabel clientInfo = new JLabel(translator.localize(LocaleResources.CLIENT_INFO).getContents());
        makeAgentUserBtn = new JCheckBox(translator.localize(LocaleResources.CREATE_AGENT_USER).getContents());
        makeAgentUserBtn.setSelected(true);
        makeClientAdminBtn = new JCheckBox(translator.localize(LocaleResources.CREATE_CLIENT_ADMIN).getContents());
        makeClientAdminBtn.setSelected(true);
        detailsPanel = new JPanel(new GridBagLayout());

        GridBagConstraints c = new GridBagConstraints();
        c.fill = GridBagConstraints.HORIZONTAL;
        c.gridy = 0;
        c.insets.top = 40;
        detailsPanel.add(agentInfo, c);
        c.gridy = 1;
        c.insets.top = 10;
        detailsPanel.add(makeAgentUserBtn, c);
        c.insets.top = 25;
        c.gridy = 2;
        detailsPanel.add(clientInfo, c);
        c.insets.top = 10;
        c.gridy = 3;
        detailsPanel.add(makeClientAdminBtn, c);

        midPanel = new JPanel(new BorderLayout());
        midPanel.add(detailsPanel, BorderLayout.NORTH);
    }

    private void createToolbarPanel() {
        URL logoURL = SetupWindow.class.getClassLoader().getResource(THERMOSTAT_LOGO);
        JLabel thermostatLogo = new JLabel(new ImageIcon(logoURL));

        backBtn = new JButton(translator.localize(LocaleResources.BACK).getContents());
        backBtn.setPreferredSize(new Dimension(70, 30));
        backBtn.setEnabled(false);
        finishBtn = new JButton(translator.localize(LocaleResources.FINISH).getContents());
        finishBtn.setPreferredSize(new Dimension(70, 30));
        cancelBtn = new JButton(translator.localize(LocaleResources.CANCEL).getContents());
        cancelBtn.setPreferredSize(new Dimension(70, 30));

        toolbar = new JPanel();
        toolbar.setLayout(new BoxLayout(toolbar, BoxLayout.LINE_AXIS));
        toolbar.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
        toolbar.add(thermostatLogo);
        toolbar.add(Box.createHorizontalGlue());
        toolbar.add(backBtn);
        toolbar.add(finishBtn);
        toolbar.add(cancelBtn);
    }

    public void enableButtons() {
        makeAgentUserBtn.setEnabled(true);
        makeClientAdminBtn.setEnabled(true);
        finishBtn.setEnabled(true);
    }

    public void disableButtons() {
        makeAgentUserBtn.setEnabled(false);
        makeClientAdminBtn.setEnabled(false);
        finishBtn.setEnabled(false);
    }

    @Override
    public Component getUiComponent() {
        return this;
    }

    public JButton getFinishBtn() {
        return finishBtn;
    }

    public JButton getCancelBtn() {
        return cancelBtn;
    }

    public boolean makeAgentUserSelected() {
        return makeAgentUserBtn.isSelected();
    }

    public boolean makeClientAdminSelected() {
        return makeClientAdminBtn.isSelected();
    }
}
